@@ -10,7 +10,7 @@ class BinanceChainAPIException(Exception):
         except ValueError:
             self.message = 'Invalid JSON error message from Binance Chain: {}'.format(response.text)
         else:
-            self.code = json_res['code']
+            self.code = json_res.get('code', None)
             self.message = json_res['message']
         self.status_code = status_code
         self.response = response
@@ -28,6 +28,10 @@ class BinanceChainBroadcastException(Exception):
     pass
 
 
+class BinanceChainSigningAuthenticationException(Exception):
+    pass
+
+
 class BinanceChainRPCException(Exception):
     def __init__(self, response):
         self.code = 0
